from setuptools import setup, find_packages
import codecs
import os

VERSION = '0.0.1'
DESCRIPTION = 'Time series classification using Deep Learning'


# Setting up
setup(
    name="romaniya",
    version=VERSION,
    author="JavidanAbdullayev (Javidan Abdullayev)",
    author_email="<javidan.abdullayev@uha.fr>",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=['numpy', 'pandas',     ],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    include_package_data=True,
    package_data={'': ['data/*.tsv']},

)




import os

def add(a, b):
    return a + b

def multiply(a, b):
    return a * b

def subtract(a, b):
    return a - b

def divide(a, b):
    return a / b

def exp(a, b):
    return a**b

def display_path():
    directory = os.getcwd()
    print(directory)